﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace ChildWindowsError.Tools
{
    /// <summary>
    /// Theme base login
    /// </summary>
    public class BaseLogin : ChildWindow
    {
        Button OKButton = null;
        Button cancelButton = null;
        /// <summary>
        /// Login form grid
        /// </summary>
        public Grid loginGrid = null;
        /// <summary>
        /// Name user
        /// </summary>
        public TextBox nameBox = null;
        /// <summary>
        /// Password user
        /// </summary>
        public PasswordBox passwordBox = null;
        /// <summary>
        /// Stack panel from login data
        /// </summary>
        public StackPanel stackPanel = null;
        CheckBox checkBox = null;
#pragma warning disable CS0414 // The field 'BaseLogin.loginPage' is assigned but its value is never used
        /// <summary>
        /// Default login partial url
        /// </summary>
        string loginPage = "/Account/Login";
#pragma warning restore CS0414 // The field 'BaseLogin.loginPage' is assigned but its value is never used
        /// <summary>
        /// Base login form constructor
        /// </summary>
        public BaseLogin()
        {
            InitializeComponents();
        }

        /// <summary>
        /// Intitialize window components
        /// </summary>
        virtual public void InitializeComponents()
        {
            this.Height = 300;
            this.Width = 400;
            this.Title = "Login window";
            this.Closing += BaseLogin_Closing;
            loginGrid = new Grid();
            //
            loginGrid.Margin = new Thickness(2);
            RowDefinition row = new RowDefinition();
            loginGrid.RowDefinitions.Add(row);
            row = new RowDefinition();
            row.Height = new GridLength(0, GridUnitType.Auto);
            loginGrid.RowDefinitions.Add(row);
            //
            stackPanel = new StackPanel();
            //
            stackPanel.Children.Add(new TextBlock() { Text = "Name" });
            nameBox = new TextBox() { Name = "nameBox" };
            stackPanel.Children.Add(nameBox);
            stackPanel.Children.Add(new TextBlock() { Text = "Password" });
            PasswordBox passwordBox = new PasswordBox() { Name = "passwordBox" };
            stackPanel.Children.Add(passwordBox);
            checkBox = new CheckBox();
            checkBox.Content = "Remember me";
            stackPanel.Children.Add(checkBox);
            //
            loginGrid.Children.Add(stackPanel);
            //
            cancelButton = new Button()
            {
                Content = "Cancel",
                Width = 75,
                Height = 23,
                HorizontalAlignment = HorizontalAlignment.Right,
                Margin = new Thickness(0, 12, 0, 0)
            };
            cancelButton.Click += CancelButton_Click;
            Grid.SetRow(cancelButton, 1);
            loginGrid.Children.Add(cancelButton);
            //
            OKButton = new Button()
            {
                Content = "Ok",
                Width = 75,
                Height = 23,
                HorizontalAlignment = HorizontalAlignment.Right,
                Margin = new Thickness(0, 12, 79, 0)
            };
            OKButton.Click += OKButton_Click;
            Grid.SetRow(OKButton, 1);
            loginGrid.Children.Add(OKButton);
            //
            this.Content = loginGrid;
        }

        private void BaseLogin_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (this.DialogResult.HasValue && this.DialogResult.Value == true &&
                (this.nameBox.Text == string.Empty || this.passwordBox.Password == string.Empty))
            {
                e.Cancel = true;
                ChildWindow cw = new ChildWindow();
                cw.Content = "Please Enter your name and password or click Cancel.";
                cw.Show();
            }
        }
        /// <summary>
        /// Get login name
        /// </summary>
        public string NameBox
        {
            get
            {
                return this.nameBox.Text;
            }
        }
        /// <summary>
        /// Get password
        /// </summary>
        public string PasswordBox
        {
            get
            {
                return this.passwordBox.Password;
            }
        }
        /// <summary>
        /// Get remember me
        /// </summary>
        public bool RememberMe
        {
            get
            {
                return (bool)(this.checkBox.IsChecked);
            }
        }
        //
        private void OKButton_Click(object sender, RoutedEventArgs e)
        {
            ValidateUser();
        }
        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            CancelValidateUser();
        }
        /// <summary>
        /// Validate user
        /// </summary>
        virtual public void ValidateUser()
        {
            // if valid user true, else false
            this.DialogResult = true;
        }
        /// <summary>
        /// Cancel validate user, set <see cref="Tehnolog.Business.Utils.LoginData"/> to null
        /// </summary>
        virtual public void CancelValidateUser()
        {
            this.DialogResult = false;
        }
    }
}
